@@ -2,6 +2,7 @@ from vectorcode.subcommands.check import check
 from vectorcode.subcommands.chunks import chunks
 from vectorcode.subcommands.clean import clean
 from vectorcode.subcommands.drop import drop
+from vectorcode.subcommands.files import files
 from vectorcode.subcommands.init import init
 from vectorcode.subcommands.ls import ls
 from vectorcode.subcommands.prompt import prompts
@@ -14,6 +15,7 @@ __all__ = [
     "chunks",
     "clean",
     "drop",
+    "files",
     "init",
     "ls",
     "prompts",
